@@ -7,7 +7,7 @@ use parent qw(Tickit::Widget Mixin::Event::Dispatch);
 
 use constant EVENT_DISPATCH_ON_FALLBACK => 0;
 
-our $VERSION = '0.108';
+our $VERSION = '0.109';
 
 =head1 NAME
 
@@ -15,7 +15,7 @@ Tickit::Widget::Tree - tree widget implementation for L<Tickit>
 
 =head1 VERSION
 
-Version 0.108
+version 0.109
 
 =head1 SYNOPSIS
 
@@ -284,6 +284,7 @@ Work out our size, when we have a window to fit in.
 sub window_gained {
 	my $self = shift;
 	$self->calculate_size;
+	$self->window->cursor_visible(0);
 	$self->SUPER::window_gained(@_);
 }
 
@@ -396,13 +397,17 @@ sub render_to_rb {
 
 		# Our label - root isn't shown, and we don't want a blank
 		# line at the top either, so we don't update the pointer for root
-		unless($node->is_root) {
+		if($node->is_root) {
+			# Bring the initial line down from the top of the window, so we don't start with
+			# an isolated line segment
+			$rb->vline_at(-1, 0, 1, LINE_SINGLE, $line_pen);
+		} else {
 			# We only need to draw this if we're inside the rendering area
 			if($start_y >= $top) {
 				$rb->hline_at(
 					$start_y,
 					1 + 3 * ($depth - 1),
-					(3 * $depth) - ($has_children ? 1 : 0),
+					(3 * $depth) - 1, # ($has_children ? 1 : 0),
 					LINE_SINGLE,
 					$line_pen,
 				) if $depth;
@@ -421,7 +426,7 @@ sub render_to_rb {
 						$highlight_pen
 					);
 				}
-				$win->cursor_at($start_y - $y_offset, (2 + 3 * ($depth - 1)) - $x_offset) if ($highlight_node == $node) && delete $self->{move_cursor};
+				$win->cursor_at($start_y - $y_offset, 2 + (2 + 3 * ($depth - 1)) - $x_offset) if ($highlight_node == $node) && delete $self->{move_cursor};
 				if($has_children) {
 					$rb->char_at(
 						$start_y,
@@ -745,4 +750,4 @@ Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2013. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2015. Licensed under the same terms as Perl itself.
